@@ -2,20 +2,25 @@
 package SQL::Statement::RAM;
 ############################
 
+use strict;
+use warnings;
+
 use vars qw($VERSION);
-$VERSION = '1.27_02';
+$VERSION = '1.32';
 
 ####################################
 package SQL::Statement::RAM::Table;
 ####################################
 
+use strict;
+use warnings;
+
 require SQL::Eval;
 
 use vars qw(@ISA);
 @ISA = qw(SQL::Eval::Table);
 
 use Carp qw(croak);
-use Clone qw(clone);
 
 sub new
 {
@@ -39,29 +44,23 @@ sub new
 sub fetch_row
 {
     my ( $self, $data ) = @_;
-    return $self->{row} = undef unless ( $self->{records} );
-    return $self->{row} = undef if ( $self->{index} >= scalar( @{ $self->{records} } ) );
-    # clone before return, otherwise modifications in fetched result will modify table
-    return $self->{row} = clone( $self->{records}->[ $self->{index}++ ] );
+
+    return $self->{row} =
+        ( $self->{records} and ( $self->{index} < scalar( @{ $self->{records} } ) ) )
+      ? [ @{ $self->{records}->[ $self->{index}++ ] } ]
+      : undef;
 }
-####################################
-# push_row()
-####################################
-#sub push_row
-#{
-#    my ( $self, $data, $fields ) = @_;
-#    $self->{records}->[ $self->{index}++ ] = clone($fields);
-#    return 1;
-#}
+
 ####################################
 # insert_new_row()
 ####################################
 sub insert_new_row
 {
     my ( $self, $data, $fields ) = @_;
-    push @{$self->{records}}, clone($fields);
+    push @{ $self->{records} }, [ @{$fields} ];
     return 1;
 }
+
 ##################################
 # delete_current_row()
 ##################################
@@ -74,6 +73,7 @@ sub delete_current_row
     --$self->{index};
     return 1;
 }
+
 ##################################
 # update_current_row()
 ##################################
@@ -82,9 +82,10 @@ sub update_current_row
     my ( $self, $data, $fields ) = @_;
     my $currentRow = $self->{index} - 1;
     croak "No current row" unless ( $currentRow >= 0 );
-    $self->{records}->[$currentRow] = clone($fields);
+    $self->{records}->[$currentRow] = [ @{$fields} ];
     return 1;
 }
+
 ##################################
 # truncate()
 ##################################
@@ -92,6 +93,7 @@ sub truncate
 {
     return splice @{ $_[0]->{records} }, $_[0]->{index};
 }
+
 #####################################
 # push_names()
 #####################################
@@ -99,9 +101,10 @@ sub push_names
 {
     my ( $self, $data, $names ) = @_;
     $self->{col_names}     = $names;
-    $self->{org_col_names} = clone($names);
+    $self->{org_col_names} = [ @{$names} ];
     $self->{col_nums}      = SQL::Eval::Table::_map_colnums($names);
 }
+
 #####################################
 # drop()
 #####################################
@@ -112,6 +115,7 @@ sub drop
     delete $data->{Database}->{sql_ram_tables}->{$tname};
     return 1;
 }
+
 #####################################
 # seek()
 #####################################
@@ -142,7 +146,7 @@ sub seek
     }
     $self->{index} = $currentRow;
 }
-############################################################################
+
 1;
 
 =pod
@@ -157,7 +161,8 @@ SQL::Statement::RAM
 
 =head1 DESCRIPTION
 
-This package contains support for the internally used SQL::Statement::RAM::Table.
+This package contains support for the internally used
+SQL::Statement::RAM::Table.
 
 =head1 INHERITANCE
 
@@ -185,7 +190,7 @@ Fetches the next row
 
 =item push_row
 
-Similar for writing
+As fetch_row except for writing
 
 =item delete_current_row
 
@@ -221,7 +226,7 @@ This table has following capabilities:
 
 =item update_current_row
 
-By providing method C<update_current_row> and capability C<inplace_update>.
+Using provided method C<update_current_row> and capability C<inplace_update>.
 
 =item rowwise_update
 
@@ -233,7 +238,7 @@ By definition (appropriate flag set in constructor).
 
 =item delete_current_row
 
-By providing method C<delete_current_row> and capability C<inplace_delete>.
+Using provided method C<delete_current_row> and capability C<inplace_delete>.
 
 =item rowwise_delete
 
